# -*- coding: utf-8 -*-
# @Time    : 2025/12/23 21:15
# @Author  : D.N. Huang
# @Email   : CarlCypress@yeah.net
# @FileName: __init__.py
# @Project : WSIRadiomics

from ._version import __version__

__all__ = ["__version__"]
